# The default site config file. This may be placed at any location in the PYTHONPATH used by CASA

# This file should be edited to set measurespath as appropriate

# Set this to point to the location where the site maintained casarundata can be found
# by default datapath will include measurespath

measurespath = None

# turn off all auto updates of data

measures_auto_update = False
data_auto_update = False